// This file was generated by qtwaylandscanner
// source file is server-decoration-palette.xml

#ifndef QT_WAYLAND_SERVER_DECORATION_PALETTE
#define QT_WAYLAND_SERVER_DECORATION_PALETTE

#include "wayland-server-decoration-palette-client-protocol.h"
#include <QByteArray>
#include <QString>

struct wl_registry;

QT_BEGIN_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_GCC("-Wmissing-field-initializers")
QT_WARNING_DISABLE_CLANG("-Wmissing-field-initializers")

namespace QtWayland {
    class  org_kde_kwin_server_decoration_palette_manager
    {
    public:
        org_kde_kwin_server_decoration_palette_manager(struct ::wl_registry *registry, uint32_t id, int version);
        org_kde_kwin_server_decoration_palette_manager(struct ::org_kde_kwin_server_decoration_palette_manager *object);
        org_kde_kwin_server_decoration_palette_manager();

        virtual ~org_kde_kwin_server_decoration_palette_manager();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::org_kde_kwin_server_decoration_palette_manager *object);

        struct ::org_kde_kwin_server_decoration_palette_manager *object() { return m_org_kde_kwin_server_decoration_palette_manager; }
        const struct ::org_kde_kwin_server_decoration_palette_manager *object() const { return m_org_kde_kwin_server_decoration_palette_manager; }
        static org_kde_kwin_server_decoration_palette_manager *fromObject(struct ::org_kde_kwin_server_decoration_palette_manager *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        struct ::org_kde_kwin_server_decoration_palette *create(struct ::wl_surface *surface);

    private:
        struct ::org_kde_kwin_server_decoration_palette_manager *m_org_kde_kwin_server_decoration_palette_manager;
    };

    class  org_kde_kwin_server_decoration_palette
    {
    public:
        org_kde_kwin_server_decoration_palette(struct ::wl_registry *registry, uint32_t id, int version);
        org_kde_kwin_server_decoration_palette(struct ::org_kde_kwin_server_decoration_palette *object);
        org_kde_kwin_server_decoration_palette();

        virtual ~org_kde_kwin_server_decoration_palette();

        void init(struct ::wl_registry *registry, uint32_t id, int version);
        void init(struct ::org_kde_kwin_server_decoration_palette *object);

        struct ::org_kde_kwin_server_decoration_palette *object() { return m_org_kde_kwin_server_decoration_palette; }
        const struct ::org_kde_kwin_server_decoration_palette *object() const { return m_org_kde_kwin_server_decoration_palette; }
        static org_kde_kwin_server_decoration_palette *fromObject(struct ::org_kde_kwin_server_decoration_palette *object);

        bool isInitialized() const;

        uint32_t version() const;
        static const struct ::wl_interface *interface();

        void set_palette(const QString &palette);
        void release();

    private:
        struct ::org_kde_kwin_server_decoration_palette *m_org_kde_kwin_server_decoration_palette;
    };
}

QT_WARNING_POP
QT_END_NAMESPACE

#endif
